==> 4.4.tar.gz: kibana/src/ui/public/vislib/__tests__/lib/dispatch.js <==
var angular = require('angular');
var _ = require('lodash');
var $ = require('jquery');
var d3 = require('d3');
var ngMock = require('ngMock');
var expect = require('expect.js');

// Data
var data = require('fixtures/vislib/mock_data/date_histogram/_series');

describe('Vislib Dispatch Class Test Suite', function () {

  function destroyVis(vis) {
    $(vis.el).remove();
    vis = null;
  }

  function getEls(el, n, type) {
    return d3.select(el).data(new Array(n)).enter().append(type);
  }

  describe('', function () {
    var vis;
    var persistedState;
    var SimpleEmitter;

    beforeEach(ngMock.module('kibana'));
    beforeEach(ngMock.inject(function (Private) {
      vis = Private(require('fixtures/vislib/_vis_fixture'))();
      persistedState = new (Private(require('ui/persisted_state/persisted_state')))();
      vis.render(data, persistedState);
      SimpleEmitter = require('ui/utils/SimpleEmitter');
    }));

    afterEach(function () {
      destroyVis(vis);
    });

    it('extends the SimpleEmitter class', function () {
      var events = _.pluck(vis.handler.charts, 'events');
      expect(events.length).to.be.above(0);
      events.forEach(function (dispatch) {
        expect(dispatch).to.be.a(SimpleEmitter);
      });
    });
  });

  describe('Stock event handlers', function () {
    var vis;
    var persistedState;

    beforeEach(ngMock.module('kibana'));
    beforeEach(ngMock.inject(function (Private) {
      vis = Private(require('fixtures/vislib/_vis_fixture'))();
      persistedState = new (Private(require('ui/persisted_state/persisted_state')))();
      vis.on('brush', _.noop);
      vis.render(data, persistedState);
    }));

    afterEach(function () {
      destroyVis(vis);
    });

    describe('addEvent method', function () {
      it('returns a function that binds the passed event to a selection', function () {
        var chart = _.first(vis.handler.charts);
        var apply = chart.events.addEvent('event', _.noop);
        expect(apply).to.be.a('function');

        var els = getEls(vis.el, 3, 'div');
        apply(els);
        els.each(function () {
          expect(d3.select(this).on('event')).to.be(_.noop);
        });
      });
    });

    // test the addHoverEvent, addClickEvent, addBrushEvent methods by
    // checking that they return function which bind the events expected
    function checkBoundAddMethod(name, event) {
      describe(name + ' method', function () {
        it('should be a function', function () {
          vis.handler.charts.forEach(function (chart) {
            expect(chart.events[name]).to.be.a('function');
          });
        });

        it('returns a function that binds ' + event + ' events to a selection', function () {
          var chart = _.first(vis.handler.charts);
          var apply = chart.events[name](d3.select(document.createElement('svg')));
          expect(apply).to.be.a('function');

          var els = getEls(vis.el, 3, 'div');
          apply(els);
          els.each(function () {
            expect(d3.select(this).on(event)).to.be.a('function');
          });
        });
      });
    }

    checkBoundAddMethod('addHoverEvent', 'mouseover');
    checkBoundAddMethod('addMouseoutEvent', 'mouseout');
    checkBoundAddMethod('addClickEvent', 'click');
    checkBoundAddMethod('addBrushEvent', 'mousedown');

    describe('addMousePointer method', function () {
      it('should be a function', function () {
        vis.handler.charts.forEach(function (chart) {
          var pointer = chart.events.addMousePointer;

          expect(_.isFunction(pointer)).to.be(true);
        });
      });
    });
  });

  describe('Custom event handlers', function () {
    it('should attach whatever gets passed on vis.on() to chart.events', function (done) {
      var vis;
      var persistedState;
      var chart;
      ngMock.module('kibana');
      ngMock.inject(function (Private) {
        vis = Private(require('fixtures/vislib/_vis_fixture'))();
        persistedState = new (Private(require('ui/persisted_state/persisted_state')))();
        vis.on('someEvent', _.noop);
        vis.render(data, persistedState);

        vis.handler.charts.forEach(function (chart) {
          expect(chart.events.listenerCount('someEvent')).to.be(1);
        });

        destroyVis(vis);
        done();
      });
    });

    it('can be added after rendering', function () {
      var vis;
      var persistedState;
      var chart;
      ngMock.module('kibana');
      ngMock.inject(function (Private) {
        vis = Private(require('fixtures/vislib/_vis_fixture'))();
        persistedState = new (Private(require('ui/persisted_state/persisted_state')))();
        vis.render(data, persistedState);
        vis.on('someEvent', _.noop);

        vis.handler.charts.forEach(function (chart) {
          expect(chart.events.listenerCount('someEvent')).to.be(1);
        });

        destroyVis(vis);
      });
    });
  });
});

==> 5.1.tar.gz: kibana/src/ui/public/vislib/__tests__/lib/dispatch.js <==
import angular from 'angular';
import _ from 'lodash';
import d3 from 'd3';
import ngMock from 'ng_mock';
import expect from 'expect.js';

// Data
import data from 'fixtures/vislib/mock_data/date_histogram/_series';
import $ from 'jquery';
import FixturesVislibVisFixtureProvider from 'fixtures/vislib/_vis_fixture';
import PersistedStatePersistedStateProvider from 'ui/persisted_state/persisted_state';

describe('Vislib Dispatch Class Test Suite', function () {

  function destroyVis(vis) {
    vis.destroy();
  }

  function getEls(el, n, type) {
    return d3.select(el).data(new Array(n)).enter().append(type);
  }

  describe('', function () {
    let vis;
    let persistedState;
    let SimpleEmitter;

    beforeEach(ngMock.module('kibana'));
    beforeEach(ngMock.inject(function (Private) {
      vis = Private(FixturesVislibVisFixtureProvider)();
      persistedState = new (Private(PersistedStatePersistedStateProvider))();
      vis.render(data, persistedState);
      SimpleEmitter = require('ui/utils/simple_emitter');
    }));

    afterEach(function () {
      destroyVis(vis);
    });

    it('extends the SimpleEmitter class', function () {
      const events = _.pluck(vis.handler.charts, 'events');
      expect(events.length).to.be.above(0);
      events.forEach(function (dispatch) {
        expect(dispatch).to.be.a(SimpleEmitter);
      });
    });
  });

  describe('Stock event handlers', function () {
    let vis;
    let persistedState;

    beforeEach(ngMock.module('kibana'));
    beforeEach(ngMock.inject(function (Private) {
      vis = Private(FixturesVislibVisFixtureProvider)();
      persistedState = new (Private(PersistedStatePersistedStateProvider))();
      vis.on('brush', _.noop);
      vis.render(data, persistedState);
    }));

    afterEach(function () {
      destroyVis(vis);
    });

    describe('addEvent method', function () {
      it('returns a function that binds the passed event to a selection', function () {
        const chart = _.first(vis.handler.charts);
        const apply = chart.events.addEvent('event', _.noop);
        expect(apply).to.be.a('function');

        const els = getEls(vis.el, 3, 'div');
        apply(els);
        els.each(function () {
          expect(d3.select(this).on('event')).to.be(_.noop);
        });
      });
    });

    // test the addHoverEvent, addClickEvent, addBrushEvent methods by
    // checking that they return function which bind the events expected
    function checkBoundAddMethod(name, event) {
      describe(name + ' method', function () {
        it('should be a function', function () {
          vis.handler.charts.forEach(function (chart) {
            expect(chart.events[name]).to.be.a('function');
          });
        });

        it('returns a function that binds ' + event + ' events to a selection', function () {
          const chart = _.first(vis.handler.charts);
          const apply = chart.events[name](d3.select(document.createElement('svg')));
          expect(apply).to.be.a('function');

          const els = getEls(vis.el, 3, 'div');
          apply(els);
          els.each(function () {
            expect(d3.select(this).on(event)).to.be.a('function');
          });
        });
      });
    }

    checkBoundAddMethod('addHoverEvent', 'mouseover');
    checkBoundAddMethod('addMouseoutEvent', 'mouseout');
    checkBoundAddMethod('addClickEvent', 'click');
    checkBoundAddMethod('addBrushEvent', 'mousedown');

    describe('addMousePointer method', function () {
      it('should be a function', function () {
        vis.handler.charts.forEach(function (chart) {
          const pointer = chart.events.addMousePointer;

          expect(_.isFunction(pointer)).to.be(true);
        });
      });
    });
  });

  describe('Custom event handlers', function () {
    it('should attach whatever gets passed on vis.on() to chart.events', function (done) {
      let vis;
      let persistedState;
      ngMock.module('kibana');
      ngMock.inject(function (Private) {
        vis = Private(FixturesVislibVisFixtureProvider)();
        persistedState = new (Private(PersistedStatePersistedStateProvider))();
        vis.on('someEvent', _.noop);
        vis.render(data, persistedState);

        vis.handler.charts.forEach(function (chart) {
          expect(chart.events.listenerCount('someEvent')).to.be(1);
        });

        destroyVis(vis);
        done();
      });
    });

    it('can be added after rendering', function () {
      let vis;
      let persistedState;
      ngMock.module('kibana');
      ngMock.inject(function (Private) {
        vis = Private(FixturesVislibVisFixtureProvider)();
        persistedState = new (Private(PersistedStatePersistedStateProvider))();
        vis.render(data, persistedState);
        vis.on('someEvent', _.noop);

        vis.handler.charts.forEach(function (chart) {
          expect(chart.events.listenerCount('someEvent')).to.be(1);
        });

        destroyVis(vis);
      });
    });
  });
});
